@@ -21,7 +21,7 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 	"sigs.k8s.io/controller-runtime/pkg/source"
 
-	hivev1 "github.com/openshift/hive/pkg/apis/hive/v1"
+	hivev1 "github.com/openshift/hive/apis/hive/v1"
 	"github.com/openshift/hive/pkg/constants"
 	hivemetrics "github.com/openshift/hive/pkg/controller/metrics"
 	controllerutils "github.com/openshift/hive/pkg/controller/utils"
@@ -35,6 +35,13 @@ const (
 	hiveClaimOwnerRoleBindingName = "hive-claim-owner"
 )
 
+// clusterClaimConditions are the cluster claim conditions controlled or initialized by cluster claim controller
+var clusterClaimConditions = []hivev1.ClusterClaimConditionType{
+	hivev1.ClusterClaimPendingCondition,
+	hivev1.ClusterClaimClusterDeletedCondition,
+	hivev1.ClusterRunningCondition,
+}
+
 // Add creates a new ClusterClaim Controller and adds it to the Manager with default RBAC. The Manager will set fields on the Controller
 // and Start it when the Manager is Started.
 func Add(mgr manager.Manager) error {
@@ -76,30 +83,21 @@ func AddToManager(mgr manager.Manager, r *ReconcileClusterClaim, concurrentRecon
 	// Watch for changes to ClusterDeployment
 	if err := c.Watch(
 		&source.Kind{Type: &hivev1.ClusterDeployment{}},
-		&handler.EnqueueRequestsFromMapFunc{
-			ToRequests: handler.ToRequestsFunc(requestsForClusterDeployment),
-		},
-	); err != nil {
+		handler.EnqueueRequestsFromMapFunc(requestsForClusterDeployment)); err != nil {
 		return err
 	}
 
 	// Watch for changes to the hive-claim-owner Role
 	if err := c.Watch(
 		&source.Kind{Type: &rbacv1.Role{}},
-		&handler.EnqueueRequestsFromMapFunc{
-			ToRequests: requestsForRBACResources(r.Client, hiveClaimOwnerRoleName, r.logger),
-		},
-	); err != nil {
+		handler.EnqueueRequestsFromMapFunc(requestsForRBACResources(r.Client, hiveClaimOwnerRoleName, r.logger))); err != nil {
 		return err
 	}
 
 	// Watch for changes to the hive-claim-owner RoleBinding
 	if err := c.Watch(
 		&source.Kind{Type: &rbacv1.Role{}},
-		&handler.EnqueueRequestsFromMapFunc{
-			ToRequests: requestsForRBACResources(r.Client, hiveClaimOwnerRoleBindingName, r.logger),
-		},
-	); err != nil {
+		handler.EnqueueRequestsFromMapFunc(requestsForRBACResources(r.Client, hiveClaimOwnerRoleBindingName, r.logger))); err != nil {
 		return err
 	}
 
@@ -119,8 +117,8 @@ func claimForClusterDeployment(cd *hivev1.ClusterDeployment) *types.NamespacedNa
 	}
 }
 
-func requestsForClusterDeployment(o handler.MapObject) []reconcile.Request {
-	cd, ok := o.Object.(*hivev1.ClusterDeployment)
+func requestsForClusterDeployment(o client.Object) []reconcile.Request {
+	cd, ok := o.(*hivev1.ClusterDeployment)
 	if !ok {
 		return nil
 	}
@@ -131,12 +129,12 @@ func requestsForClusterDeployment(o handler.MapObject) []reconcile.Request {
 	return []reconcile.Request{{NamespacedName: *claim}}
 }
 
-func requestsForRBACResources(c client.Client, resourceName string, logger log.FieldLogger) handler.ToRequestsFunc {
-	return func(o handler.MapObject) []reconcile.Request {
-		if o.Meta.GetName() != resourceName {
+func requestsForRBACResources(c client.Client, resourceName string, logger log.FieldLogger) handler.MapFunc {
+	return func(o client.Object) []reconcile.Request {
+		if o.GetName() != resourceName {
 			return nil
 		}
-		clusterName := o.Meta.GetNamespace()
+		clusterName := o.GetNamespace()
 		cd := &hivev1.ClusterDeployment{}
 		if err := c.Get(context.Background(), client.ObjectKey{Namespace: clusterName, Name: clusterName}, cd); err != nil {
 			logger.WithError(err).Log(controllerutils.LogLevel(err), "failed to get ClusterDeployment for RBAC resource")
@@ -159,7 +157,7 @@ type ReconcileClusterClaim struct {
 }
 
 // Reconcile reconciles a ClusterClaim.
-func (r *ReconcileClusterClaim) Reconcile(request reconcile.Request) (result reconcile.Result, returnErr error) {
+func (r *ReconcileClusterClaim) Reconcile(ctx context.Context, request reconcile.Request) (result reconcile.Result, returnErr error) {
 	logger := controllerutils.BuildControllerLogger(ControllerName, "clusterClaim", request.NamespacedName)
 	logger.Infof("reconciling cluster claim")
 	recobsrv := hivemetrics.NewReconcileObserver(ControllerName, logger)
@@ -178,6 +176,18 @@ func (r *ReconcileClusterClaim) Reconcile(request reconcile.Request) (result rec
 		return reconcile.Result{}, err
 	}
 
+	// Initialize cluster claim conditions if not set
+	newConditions := controllerutils.InitializeClusterClaimConditions(claim.Status.Conditions, clusterClaimConditions)
+	if len(newConditions) > len(claim.Status.Conditions) {
+		claim.Status.Conditions = newConditions
+		logger.Infof("initializing cluster claim conditions")
+		if err := r.Status().Update(context.TODO(), claim); err != nil {
+			logger.WithError(err).Log(controllerutils.LogLevel(err), "failed to update cluster claim status")
+			return reconcile.Result{}, err
+		}
+		return reconcile.Result{}, nil
+	}
+
 	if claim.DeletionTimestamp != nil {
 		return r.reconcileDeletedClaim(claim, logger)
 	}
@@ -200,11 +210,27 @@ func (r *ReconcileClusterClaim) Reconcile(request reconcile.Request) (result rec
 
 	logger = logger.WithField("cluster", clusterName)
 
+	poolLifetime, err := r.clusterPoolLifetimeForClaim(claim, logger)
+	if err != nil {
+		logger.Log(controllerutils.LogLevel(err), "error getting cluster pool lifetime")
+		return reconcile.Result{}, err
+	}
+	lifetime := getClaimLifetime(poolLifetime, claim.Spec.Lifetime)
+
+	if (lifetime != nil) != (claim.Status.Lifetime != nil) ||
+		lifetime != nil && claim.Status.Lifetime != nil && lifetime.Duration != claim.Status.Lifetime.Duration {
+		claim.Status.Lifetime = lifetime
+		if err := r.Status().Update(context.Background(), claim); err != nil {
+			logger.WithError(err).Log(controllerutils.LogLevel(err), "could not update ClusterClaim lifetime")
+			return reconcile.Result{}, errors.Wrap(err, "could not update ClusterClaim lifetime")
+		}
+	}
+
 	// Delete ClusterClaim after its lifetime elapses
-	if lifetime := claim.Spec.Lifetime; lifetime != nil {
+	if lifetime != nil {
 		logger.WithField("lifetime", lifetime).Debug("checking whether lifetime of ClusterClaim has elapsed")
 		pendingCond := controllerutils.FindClusterClaimCondition(claim.Status.Conditions, hivev1.ClusterClaimPendingCondition)
-		if pendingCond != nil && pendingCond.Status == corev1.ConditionFalse {
+		if pendingCond.Status == corev1.ConditionFalse {
 			if timeSinceAssigned := time.Since(pendingCond.LastTransitionTime.Time); timeSinceAssigned >= lifetime.Duration {
 				logger.WithField("timeSinceAssigned", timeSinceAssigned).
 					WithField("lifetime", lifetime).
@@ -217,7 +243,7 @@ func (r *ReconcileClusterClaim) Reconcile(request reconcile.Request) (result rec
 			}
 			defer func() {
 				result, returnErr = controllerutils.EnsureRequeueAtLeastWithin(
-					claim.Spec.Lifetime.Duration-time.Since(pendingCond.LastTransitionTime.Time),
+					lifetime.Duration-time.Since(pendingCond.LastTransitionTime.Time),
 					result,
 					returnErr,
 				)
@@ -244,6 +270,47 @@ func (r *ReconcileClusterClaim) Reconcile(request reconcile.Request) (result rec
 	}
 }
 
+// getClaimLifetime returns the lifetime for a claim taking into account the lifetime set on the pool
+// and the claim.
+// if no lifetime is set on the claim, the default lifetime for the pool is used if set.
+// if maximum lifetime for the pool, the lifetime is minimum of this maximum and lifetime from above.
+func getClaimLifetime(poolLifetime *hivev1.ClusterPoolClaimLifetime, claimLifetime *metav1.Duration) *metav1.Duration {
+	var lifetime *metav1.Duration
+	if poolLifetime != nil && poolLifetime.Default != nil {
+		lifetime = poolLifetime.Default
+	}
+	if claimLifetime != nil {
+		lifetime = claimLifetime
+	}
+	if poolLifetime != nil && poolLifetime.Maximum != nil {
+		if lifetime == nil ||
+			(poolLifetime.Maximum.Duration < lifetime.Duration) {
+			lifetime = poolLifetime.Maximum
+		}
+
+	}
+	return lifetime
+}
+
+// clusterPoolLifetimeForClaim returns the default and max lifetimes for the cluster pool the claim belongs to.
+func (r *ReconcileClusterClaim) clusterPoolLifetimeForClaim(claim *hivev1.ClusterClaim, logger log.FieldLogger) (*hivev1.ClusterPoolClaimLifetime, error) {
+	// Fetch the ClusterPool instance
+	clp := &hivev1.ClusterPool{}
+	// claims exists in the same namespace as the pool
+	key := client.ObjectKey{Namespace: claim.Namespace, Name: claim.Spec.ClusterPoolName}
+	err := r.Get(context.TODO(), key, clp)
+	if apierrors.IsNotFound(err) {
+		logger.WithField("pool", key).WithField("claim", claim.Name).Info("cluster pool no longer exists")
+		// since there is no pool no lifetime can be extracted. this is a valid state.
+		return nil, nil
+	}
+	if err != nil {
+		log.WithError(err).Error("error reading cluster pool")
+		return nil, errors.Wrap(err, "failed to get the pool")
+	}
+	return clp.Spec.ClaimLifetime, nil
+}
+
 func (r *ReconcileClusterClaim) reconcileDeletedClaim(claim *hivev1.ClusterClaim, logger log.FieldLogger) (reconcile.Result, error) {
 	if !controllerutils.HasFinalizer(claim, finalizer) {
 		return reconcile.Result{}, nil
@@ -374,7 +441,7 @@ func (r *ReconcileClusterClaim) reconcileForExistingAssignment(claim *hivev1.Clu
 	statusChanged = statusChanged || changed
 
 	hc := controllerutils.FindClusterDeploymentCondition(cd.Status.Conditions, hivev1.ClusterHibernatingCondition)
-	if hc == nil || hc.Status == corev1.ConditionFalse {
+	if hc.Status == corev1.ConditionFalse {
 		conds, changed = controllerutils.SetClusterClaimConditionWithChangeCheck(
 			conds,
 			hivev1.ClusterRunningCondition,
