@@ -13,9 +13,10 @@ import (
 	"github.com/prometheus/client_golang/prometheus"
 	log "github.com/sirupsen/logrus"
 
-	hivev1 "github.com/openshift/hive/pkg/apis/hive/v1"
+	hivev1 "github.com/openshift/hive/apis/hive/v1"
 	awsclient "github.com/openshift/hive/pkg/awsclient"
 	"github.com/openshift/hive/pkg/azureclient"
+	"github.com/openshift/hive/pkg/constants"
 	hivemetrics "github.com/openshift/hive/pkg/controller/metrics"
 	controllerutils "github.com/openshift/hive/pkg/controller/utils"
 	gcpclient "github.com/openshift/hive/pkg/gcpclient"
@@ -28,6 +29,7 @@ import (
 	"k8s.io/client-go/util/workqueue"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/controller"
+	"sigs.k8s.io/controller-runtime/pkg/event"
 	"sigs.k8s.io/controller-runtime/pkg/handler"
 	"sigs.k8s.io/controller-runtime/pkg/manager"
 	"sigs.k8s.io/controller-runtime/pkg/metrics"
@@ -46,6 +48,8 @@ const (
 	accessGrantedReason             = "AccessGranted"
 	authenticationFailedReason      = "AuthenticationFailed"
 	authenticationSucceededReason   = "AuthenticationSucceeded"
+	dnsCloudErrorReason             = "CloudError"
+	dnsNoErrorReason                = "NoError"
 )
 
 var (
@@ -96,14 +100,17 @@ func add(mgr manager.Manager, r *ReconcileDNSZone, concurrentReconciles int, rat
 	}
 
 	// Watch for changes to DNSZone
-	if err := c.Watch(&source.Kind{Type: &hivev1.DNSZone{}}, &handler.EnqueueRequestForObject{}); err != nil {
+	if err := c.Watch(&source.Kind{Type: &hivev1.DNSZone{}}, controllerutils.NewRateLimitedUpdateEventHandler(&handler.EnqueueRequestForObject{}, IsErrorUpdateEvent)); err != nil {
 		return err
 	}
 
 	// Watch for changes to ClusterDeployment
 	if err := c.Watch(
 		&source.Kind{Type: &hivev1.ClusterDeployment{}},
-		controllerutils.EnqueueDNSZonesOwnedByClusterDeployment(r, r.logger),
+		controllerutils.NewRateLimitedUpdateEventHandler(
+			controllerutils.EnqueueDNSZonesOwnedByClusterDeployment(r, r.logger),
+			IsClusterDeploymentDNSErrorUpdateEvent,
+		),
 	); err != nil {
 		return err
 	}
@@ -126,7 +133,7 @@ type ReconcileDNSZone struct {
 
 // Reconcile reads that state of the cluster for a DNSZone object and makes changes based on the state read
 // and what is in the DNSZone.Spec
-func (r *ReconcileDNSZone) Reconcile(request reconcile.Request) (reconcile.Result, error) {
+func (r *ReconcileDNSZone) Reconcile(ctx context.Context, request reconcile.Request) (reconcile.Result, error) {
 	dnsLog := controllerutils.BuildControllerLogger(ControllerName, "dnsZone", request.NamespacedName)
 	dnsLog.Info("reconciling dns zone")
 	recobsrv := hivemetrics.NewReconcileObserver(ControllerName, dnsLog)
@@ -147,6 +154,19 @@ func (r *ReconcileDNSZone) Reconcile(request reconcile.Request) (reconcile.Resul
 	}
 
 	if result, err := controllerutils.ReconcileDNSZoneForRelocation(r.Client, dnsLog, desiredState, hivev1.FinalizerDNSZone); err != nil {
+		var changed bool
+		desiredState.Status.Conditions, changed = controllerutils.SetDNSZoneConditionWithChangeCheck(
+			desiredState.Status.Conditions,
+			hivev1.GenericDNSErrorsCondition,
+			corev1.ConditionTrue,
+			"RelocationError",
+			controllerutils.ErrorScrub(err),
+			controllerutils.UpdateConditionIfReasonOrMessageChange)
+		if changed {
+			if err := r.Status().Update(context.Background(), desiredState); err != nil {
+				dnsLog.WithError(err).Log(controllerutils.LogLevel(err), "failed to update dnszone status")
+			}
+		}
 		return reconcile.Result{}, err
 	} else if result != nil {
 		return *result, nil
@@ -165,8 +185,8 @@ func (r *ReconcileDNSZone) Reconcile(request reconcile.Request) (reconcile.Resul
 		return reconcile.Result{}, nil
 	}
 
-	actuator, err := r.getActuator(desiredState, dnsLog)
-	if err != nil {
+	actuator, actErr := r.getActuator(desiredState, dnsLog)
+	if actErr != nil {
 		// Handle an edge case here where if the DNSZone has been deleted, it has its finalizer, the actuator couldn't be
 		// created (presumably because creds secret is absent), and our namespace is terminated, we know we've entered a bad state
 		// where we must give up and remove the finalizer. A followup fix should prevent this problem from
@@ -194,11 +214,24 @@ func (r *ReconcileDNSZone) Reconcile(request reconcile.Request) (reconcile.Resul
 				// This returns whether there was an error or not.
 				// This is desired so that on success, this dnszone is NOT requeued. Falling through
 				// would cause a requeue because of the actuator erroring.
-				return reconcile.Result{}, err
+				return reconcile.Result{}, actErr
 			}
 		}
 
-		dnsLog.WithError(err).Error("error instantiating actuator")
+		dnsLog.WithError(actErr).Error("error instantiating actuator")
+		var changed bool
+		desiredState.Status.Conditions, changed = controllerutils.SetDNSZoneConditionWithChangeCheck(
+			desiredState.Status.Conditions,
+			hivev1.GenericDNSErrorsCondition,
+			corev1.ConditionTrue,
+			"ActuatorNotInitialized",
+			"error instantiating actuator: "+controllerutils.ErrorScrub(actErr),
+			controllerutils.UpdateConditionIfReasonOrMessageChange)
+		if changed {
+			if err := r.Status().Update(context.Background(), desiredState); err != nil {
+				dnsLog.WithError(err).Log(controllerutils.LogLevel(err), "failed to update dnszone status")
+			}
+		}
 		return reconcile.Result{}, err
 	}
 
@@ -338,18 +371,21 @@ func shouldSync(desiredState *hivev1.DNSZone) (bool, time.Duration) {
 
 func (r *ReconcileDNSZone) getActuator(dnsZone *hivev1.DNSZone, dnsLog log.FieldLogger) (Actuator, error) {
 	if dnsZone.Spec.AWS != nil {
-		secret := &corev1.Secret{}
-		err := r.Get(context.TODO(),
-			types.NamespacedName{
-				Name:      dnsZone.Spec.AWS.CredentialsSecretRef.Name,
+		credentials := awsclient.CredentialsSource{
+			Secret: &awsclient.SecretCredentialsSource{
+				Ref:       &dnsZone.Spec.AWS.CredentialsSecretRef,
 				Namespace: dnsZone.Namespace,
 			},
-			secret)
-		if err != nil {
-			return nil, err
+			AssumeRole: &awsclient.AssumeRoleCredentialsSource{
+				SecretRef: corev1.SecretReference{
+					Namespace: controllerutils.GetHiveNamespace(),
+					Name:      os.Getenv(constants.HiveAWSServiceProviderCredentialsSecretRefEnvVar),
+				},
+				Role: dnsZone.Spec.AWS.CredentialsAssumeRole,
+			},
 		}
 
-		return NewAWSActuator(dnsLog, secret, dnsZone, awsclient.NewClientFromSecret)
+		return NewAWSActuator(dnsLog, r.Client, credentials, dnsZone, awsclient.New)
 	}
 
 	if dnsZone.Spec.GCP != nil {
@@ -476,3 +512,78 @@ func lookupSOARecord(zone string, logger log.FieldLogger) (bool, error) {
 	}
 	return false, nil
 }
+
+// IsErrorUpdateEvent returns true when the update event for DNSZone is from
+// error state.
+func IsErrorUpdateEvent(evt event.UpdateEvent) bool {
+	new, ok := evt.ObjectNew.(*hivev1.DNSZone)
+	if !ok {
+		return false
+	}
+	if len(new.Status.Conditions) == 0 {
+		return false
+	}
+
+	old, ok := evt.ObjectOld.(*hivev1.DNSZone)
+	if !ok {
+		return false
+	}
+
+	errorConds := []hivev1.DNSZoneConditionType{
+		hivev1.InsufficientCredentialsCondition,
+		hivev1.AuthenticationFailureCondition,
+	}
+
+	for _, cond := range errorConds {
+		cn := controllerutils.FindDNSZoneCondition(new.Status.Conditions, cond)
+		if cn != nil && cn.Status == corev1.ConditionTrue {
+			co := controllerutils.FindDNSZoneCondition(old.Status.Conditions, cond)
+			if co == nil {
+				return true // newly added failure condition
+			}
+			if co.Status != corev1.ConditionTrue {
+				return true // newly Failed failure condition
+			}
+			if cn.Message != co.Message ||
+				cn.Reason != co.Reason {
+				return true // already failing but change in error reported
+			}
+		}
+	}
+
+	return false
+}
+
+// IsClusterDeploymentDNSErrorUpdateEvent returns true when the update event in ClusterDeployment
+// is from DNS error state.
+func IsClusterDeploymentDNSErrorUpdateEvent(evt event.UpdateEvent) bool {
+	new, ok := evt.ObjectNew.(*hivev1.ClusterDeployment)
+	if !ok {
+		return false
+	}
+	if len(new.Status.Conditions) == 0 {
+		return false
+	}
+
+	old, ok := evt.ObjectOld.(*hivev1.ClusterDeployment)
+	if !ok {
+		return false
+	}
+
+	cn := controllerutils.FindClusterDeploymentCondition(new.Status.Conditions, hivev1.DNSNotReadyCondition)
+	if cn != nil && cn.Status == corev1.ConditionTrue {
+		co := controllerutils.FindClusterDeploymentCondition(old.Status.Conditions, hivev1.DNSNotReadyCondition)
+		if co == nil {
+			return true // newly added failure condition
+		}
+		if co.Status != corev1.ConditionTrue {
+			return true // newly Failed failure condition
+		}
+		if cn.Message != co.Message ||
+			cn.Reason != co.Reason {
+			return true // already failing but change in error reported
+		}
+	}
+
+	return false
+}
